@@ -1,29 +1,7 @@
-/*
- * wreport/conv - Unit conversions
- *
- * Copyright (C) 2005--2010  ARPA-SIM <urpsim@smr.arpa.emr.it>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- *
- * Author: Enrico Zini <enrico@enricozini.com>
- */
-
 #ifndef WREPORT_CONV
 #define WREPORT_CONV
 
 /** @file
- * @ingroup conv
  * Unit conversion functions.
  */
 
@@ -69,7 +47,7 @@ int convert_degrees_to_octants(double from);
  * Convert vertical sounding significance from the AOF encoding to BUFR code
  * table 08001.
  */
-int convert_AOFVSS_to_BUFR08042(int from);
+unsigned convert_AOFVSS_to_BUFR08042(unsigned from);
 
 /**
  * Conversion functions between various code tables
@@ -100,9 +78,9 @@ int convert_BUFR20003_to_WMO4677(int from);
 /** Past weather */
 int convert_BUFR20004_to_WMO4561(int from);
 /** Vertical sounding significance */
-int convert_BUFR08001_to_BUFR08042(int from);
+unsigned convert_BUFR08001_to_BUFR08042(unsigned from);
 /** Vertical sounding significance */
-int convert_BUFR08042_to_BUFR08001(int from);
+unsigned convert_BUFR08042_to_BUFR08001(unsigned from);
 /* @} */
 
 /**
@@ -130,5 +108,4 @@ double convert_units_get_mul(const char* from, const char* to);
 bool convert_units_allowed(const char* from, const char* to);
 }
 
-/* vim:set ts=4 sw=4: */
 #endif
