@@ -1,6 +1,7 @@
 #ifndef WREPORT_FWD_H
 #define WREPORT_FWD_H
 
+#include <wreport/version.h>
 #include <cstdint>
 
 namespace wreport {
@@ -13,6 +14,12 @@ typedef uint16_t Varcode;
 class Bulletin;
 class BufrBulletin;
 class CrexBulletin;
+
+class BufrTableID;
+class CrexTableID;
+
+class Tables;
+class DTable;
 }
 
 #endif
