@@ -12,9 +12,9 @@
 #include <sys/time.h>
 #include <fcntl.h>
 #include <sys/types.h>
-#include <sys/sendfile.h>
 #include <utime.h>
 #include <alloca.h>
+#include <algorithm>
 
 namespace {
 
@@ -295,6 +295,26 @@ size_t FileDescriptor::read(void* buf, size_t count)
     return res;
 }
 
+bool FileDescriptor::read_all_or_retry(void* buf, size_t count)
+{
+    char* dest = (char*)buf;
+    size_t remaining = count;
+    while (remaining > 0)
+    {
+        size_t res = read(dest, remaining);
+        if (res == 0)
+        {
+            if (remaining == count)
+                return false;
+
+            throw_runtime_error("partial read before EOF");
+        }
+        dest += res;
+        remaining -= res;
+    }
+    return true;
+}
+
 void FileDescriptor::read_all_or_throw(void* buf, size_t count)
 {
     size_t res = read(buf, count);
@@ -403,62 +423,18 @@ bool FileDescriptor::ofd_getlk(struct flock& lk)
     return lk.l_type == F_UNLCK;
 }
 
-namespace {
-
-struct TransferBuffer
+int FileDescriptor::getfl()
 {
-    char* buf = nullptr;
-
-    ~TransferBuffer()
-    {
-        delete[] buf;
-    }
-
-    void allocate()
-    {
-        if (buf)
-            return;
-        buf = new char[40960];
-    }
-
-    operator char*() { return buf; }
-};
-
+    int res = fcntl(fd, F_GETFL, 0);
+    if (res == -1)
+        throw_error("cannot get file flags (fcntl F_GETFL)");
+    return res;
 }
 
-void FileDescriptor::sendfile(FileDescriptor& out_fd, off_t offset, size_t count)
+void FileDescriptor::setfl(int flags)
 {
-    bool has_sendfile = true;
-    TransferBuffer buffer;
-    while (count > 0)
-    {
-        if (has_sendfile)
-        {
-            ssize_t res = ::sendfile(out_fd, fd, &offset, count);
-            if (res < 0)
-            {
-                if (errno == EINVAL || errno == ENOSYS)
-                {
-                    has_sendfile = false;
-                    buffer.allocate();
-                }
-                else
-                {
-                    std::stringstream msg;
-                    msg << "cannot sendfile() " << count << " bytes from offset" << offset;
-                    throw_error(msg.str().c_str());
-                }
-            } else {
-                offset += res;
-                count -= res;
-            }
-        } else {
-            size_t res = pread(buffer, count, offset);
-            out_fd.write_all_or_retry(buffer, res);
-            offset += res;
-            count -= res;
-        }
-    }
+    if (fcntl(fd, F_SETFL, flags) == -1)
+        throw_error("cannot set file flags (fcntl F_SETFL)");
 }
 
 void FileDescriptor::futimens(const struct ::timespec ts[2])
@@ -557,28 +533,32 @@ ManagedNamedFileDescriptor& ManagedNamedFileDescriptor::operator=(ManagedNamedFi
  * Path
  */
 
-Path::Path(const char* pathname, int flags)
+Path::Path(const char* pathname, int flags, mode_t mode)
     : ManagedNamedFileDescriptor(-1, pathname)
 {
-    fd = open(pathname, flags | O_PATH);
-    if (fd == -1)
-        throw_error("cannot open path");
+    open(flags, mode);
 }
 
-Path::Path(const std::string& pathname, int flags)
+Path::Path(const std::string& pathname, int flags, mode_t mode)
     : ManagedNamedFileDescriptor(-1, pathname)
 {
-    fd = open(pathname.c_str(), flags | O_PATH);
-    if (fd == -1)
-        throw_error("cannot open path");
+    open(flags, mode);
 }
 
-Path::Path(Path& parent, const char* pathname, int flags)
-    : ManagedNamedFileDescriptor(parent.openat(pathname, flags | O_PATH),
+Path::Path(Path& parent, const char* pathname, int flags, mode_t mode)
+    : ManagedNamedFileDescriptor(parent.openat(pathname, flags | O_PATH, mode),
             str::joinpath(parent.name(), pathname))
 {
 }
 
+void Path::open(int flags, mode_t mode)
+{
+    close();
+    fd = ::open(pathname.c_str(), flags | O_PATH, mode);
+    if (fd == -1)
+        throw_error("cannot open path");
+}
+
 DIR* Path::fdopendir()
 {
     int fd1 = ::openat(fd, ".", O_DIRECTORY);
@@ -670,12 +650,43 @@ void Path::unlinkat(const char* pathname)
         throw_error("cannot unlinkat");
 }
 
+void Path::mkdirat(const char* pathname, mode_t mode)
+{
+    if (::mkdirat(fd, pathname, mode) == -1)
+        throw_error("cannot mkdirat");
+}
+
 void Path::rmdirat(const char* pathname)
 {
     if (::unlinkat(fd, pathname, AT_REMOVEDIR) == -1)
         throw_error("cannot unlinkat");
 }
 
+void Path::symlinkat(const char* target, const char* linkpath)
+{
+    if (::symlinkat(target, fd, linkpath) == -1)
+        throw_error("cannot symlinkat");
+}
+
+std::string Path::readlinkat(const char* pathname)
+{
+    std::string res(256, 0);
+    while (true)
+    {
+        // TODO: remove the cast to char* after C++14
+        ssize_t sz = ::readlinkat(fd, pathname, (char*)res.data(), res.size());
+        if (sz == -1)
+            throw_error("cannot readlinkat");
+        if (sz < (ssize_t)res.size())
+        {
+            res.resize(sz);
+            return res;
+        }
+        res.resize(res.size() * 2);
+    }
+}
+
+
 Path::iterator::iterator()
 {
 }
@@ -839,6 +850,30 @@ void Path::rmtree()
     rmdir(name());
 }
 
+std::string Path::mkdtemp(const std::string& prefix)
+{
+    char* fbuf = (char*)alloca(prefix.size() + 7);
+    memcpy(fbuf, prefix.data(), prefix.size());
+    memcpy(fbuf + prefix.size(), "XXXXXX", 7);
+    return mkdtemp(fbuf);
+}
+
+std::string Path::mkdtemp(const char* prefix)
+{
+    size_t prefix_size = strlen(prefix);
+    char* fbuf = (char*)alloca(prefix_size + 7);
+    memcpy(fbuf, prefix, prefix_size);
+    memcpy(fbuf + prefix_size, "XXXXXX", 7);
+    return mkdtemp(fbuf);
+}
+
+std::string Path::mkdtemp(char* pathname_template)
+{
+    if (char* pathname = ::mkdtemp(pathname_template))
+        return pathname;
+    throw std::system_error(errno, std::system_category(), std::string("mkdtemp failed on ") + pathname_template);
+}
+
 /*
  * File
  */
@@ -897,6 +932,10 @@ File File::mkstemp(char* pathname_template)
 }
 
 
+/*
+ * Tempfile
+ */
+
 Tempfile::Tempfile() : sys::File(sys::File::mkstemp("")) {}
 Tempfile::Tempfile(const std::string& prefix) : sys::File(sys::File::mkstemp(prefix)) {}
 Tempfile::Tempfile(const char* prefix) : sys::File(sys::File::mkstemp(prefix)) {}
@@ -918,6 +957,29 @@ void Tempfile::unlink()
 }
 
 
+/*
+ * Tempdir
+ */
+
+Tempdir::Tempdir() : sys::Path(sys::Path::mkdtemp("")) {}
+Tempdir::Tempdir(const std::string& prefix) : sys::Path(sys::Path::mkdtemp(prefix)) {}
+Tempdir::Tempdir(const char* prefix) : sys::Path(sys::Path::mkdtemp(prefix)) {}
+
+Tempdir::~Tempdir()
+{
+    if (m_rmtree_on_exit)
+        try {
+            rmtree();
+        } catch (...) {
+        }
+}
+
+void Tempdir::rmtree_on_exit(bool val)
+{
+    m_rmtree_on_exit = val;
+}
+
+
 std::string read_file(const std::string& file)
 {
     File in(file, O_RDONLY);
